Increase timer to wait for radio power off to 20 seconds

Bug: 294132749
Test: run cts -m CtsTelephonyTestCases

Change-Id: I88262c69f75c32147280b5c6f21c3966aa6fb62f
diff --git a/tests/tests/telephony/current/src/android/telephony/cts/TelephonyManagerTest.java b/tests/tests/telephony/current/src/android/telephony/cts/TelephonyManagerTest.java
index 51b8d7f..7886fa2 100644
--- a/tests/tests/telephony/current/src/android/telephony/cts/TelephonyManagerTest.java
+++ b/tests/tests/telephony/current/src/android/telephony/cts/TelephonyManagerTest.java
@@ -5826,7 +5826,7 @@
             implements TelephonyCallback.ServiceStateListener,
             TelephonyCallback.RadioPowerStateListener {
         private static final long TIMEOUT_TO_WAIT_FOR_DESIRED_STATE =
-                TimeUnit.SECONDS.toMillis(15);
+                TimeUnit.SECONDS.toMillis(20);
         private final Object mPowerStateLock = new Object();
         private final Object mServiceStateLock = new Object();
         ServiceState mServiceState;
@@ -5869,7 +5869,7 @@
                 mDesireRadioPowerState = desiredRadioState;
                 /**
                  * Since SST sets waiting time up to 10 seconds for the power off radio, the
                  * RadioStateIntent timer extends the wait time up to 15 seconds here as well.
                  */
                 waitForDesiredState(mPowerStateLock, desiredRadioState,
                         () -> mRadioPowerState, true);
@@ -5869,7 +5869,7 @@
                 /**
                  * Since SST sets waiting time up to 10 seconds for the power off radio, the
-                 * RadioStateIntent timer extends the wait time up to 15 seconds here as well.
+                 * RadioStateIntent timer extends the wait time up to 20 seconds here as well.
                  */
                 waitForDesiredState(mPowerStateLock, desiredRadioState,